# Generated by Django 3.1.5 on 2021-01-30 16:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0012_add_event_received_at_timestamp"),
    ]

    operations = [
        migrations.AlterField(
            model_name="report",
            name="report_type",
            field=models.CharField(
                choices=[
                    ("document", "Document"),
                    (
                        "document_with_address_information",
                        "Document with Address Information",
                    ),
                    (
                        "document_with_driving_licence_information",
                        "Document with Driving Licence Information",
                    ),
                    ("facial_similarity_photo", "Facial Similarity (photo)"),
                    ("facial_similarity_photo_fully_auto", "Facial Similarity (auto)"),
                    ("facial_similarity_video", "Facial Similarity (video)"),
                    ("known_faces", "Known Faces"),
                    ("identity_enhanced", "Identity (enhanced)"),
                    ("watchlist_enhanced", "Watchlist (enhanced)"),
                    ("watchlist_standard", "Watchlist"),
                    ("watchlist_peps_only", "Watchlist (PEPs only)"),
                    ("watchlist_sanctions_only", "Watchlist (sanctions only)"),
                    ("proof_of_address", "Proof of Address"),
                    ("right_to_work", "Right to Work"),
                    ("identity", "x Identity report (deprecated)"),
                    ("street_level", "x Street level report (deprecated)"),
                    ("facial_similarity", "x Facial similarity report (deprecated)"),
                    ("credit", "x Credit report (deprecated)"),
                    ("criminal_history", "x Criminal history (deprecated)"),
                    ("ssn_trace", "SSN trace (deprecated)"),
                ],
                help_text="The name of the report - see https://documentation.onfido.com/#reports",
                max_length=50,
            ),
        ),
    ]
