# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-11-15 22:50
from __future__ import unicode_literals

from django.db import migrations

from ..compat import JSONField


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0009_add_is_clear_field"),
    ]

    operations = [
        migrations.AlterField(
            model_name="applicant",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="check",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="report",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="event",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
    ]
